﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Rewards2Model
{
   using System;
   using System.Data.Entity;
   using System.Data.Entity.Infrastructure;

   // Added for manual data mapping.
   using System.Data.Entity;
   using System.Data.Entity.ModelConfiguration;
   using System.ComponentModel.DataAnnotations.Schema;

   public partial class Rewards2ModelContainer : DbContext
   {
      public Rewards2ModelContainer()
         : base("name=Rewards2ConnectionString")
      {
      }

      // Create properties to access the POCO classes.
      public DbSet<People> People { get; set; }
      public DbSet<Purchases> Purchases { get; set; }

      // Perform some manual mapping of the data.
      protected override void OnModelCreating(DbModelBuilder MB)
      {
         // Load the custom configuration.
         MB.Configurations.Add(new PeopleMap());
         MB.Configurations.Add(new CustomerMap());
         MB.Configurations.Add(new EmployeeMap());
         MB.Configurations.Add(new ManagerMap());
      }
   }

   public class PeopleMap : EntityTypeConfiguration<People>
   {
      public PeopleMap()
      {
         // Specify the name of the table to use.
         this.ToTable("People");

         // Define the key for this table.
         this.HasKey(key => key.Id);

         // Specify the mapping for each of the table properties.
         this.Property(prop => prop.Id)
            .HasColumnName("Id")
            .HasColumnType("int")
            .HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity)
            .IsRequired();

         this.Property(prop => prop.Name)
            .HasColumnName("Name")
            .HasColumnType("nvarchar")
            .IsRequired();
      }
   }

   public class CustomerMap : EntityTypeConfiguration<Customers>
   {
      public CustomerMap()
      {
         // Specify the name of the table to use.
         this.ToTable("People_Customers");

         // Define the key for this table.
         this.HasKey(key => key.Id);

         // Specify the mapping for each of the table properties.
         this.Property(prop => prop.Id)
            .HasColumnName("Id")
            .HasColumnType("int")
            .IsRequired();

         this.Property(prop => prop.CustomerType)
            .HasColumnName("CustomerType")
            .HasColumnType("int")
            .IsRequired();

         this.Property(prop => prop.Discount)
            .HasColumnName("Discount")
            .HasColumnType("decimal")
            .IsOptional();
      }
   }

   public class EmployeeMap : EntityTypeConfiguration<Employees>
   {
      public EmployeeMap()
      {
         // Specify the name of the table to use.
         this.ToTable("People_Employees");

         // Define the key for this table.
         this.HasKey(key => key.Id);

         // Specify the mapping for each of the table properties.
         this.Property(prop => prop.Id)
            .HasColumnName("Id")
            .HasColumnType("int")
            .IsRequired();

         this.Property(prop => prop.EmployeeType)
            .HasColumnName("EmployeeType")
            .HasColumnType("int")
            .IsRequired();
      }
   }

   public class ManagerMap : EntityTypeConfiguration<Managers>
   {
      public ManagerMap()
      {
         // Specify the name of the table to use.
         this.ToTable("People_Managers");

         // Define the key for this table.
         this.HasKey(key => key.Id);

         // Specify the mapping for each of the table properties.
         this.Property(prop => prop.Id)
            .HasColumnName("Id")
            .HasColumnType("int")
            .IsRequired();

         this.Property(prop => prop.Discount)
            .HasColumnName("Discount")
            .HasColumnType("decimal")
            .IsOptional();
      }
   }
}
